#
# spec file for package bitlbee-facebook
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define from_checkout 1
Name:           bitlbee-facebook
Version:        1.2.2+git.1614281748.a31ccbe
Release:        1.15
Summary:        The Facebook protocol plugin for bitlbee
License:        GPL-2.0-only
Group:          Productivity/Networking/IRC
URL:            https://github.com/bitlbee/bitlbee-facebook
%if 0%{?from_checkout}
Source:         %{name}-%{version}.tar.gz
%else
Source:         https://github.com/bitlbee/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bitlbee)
BuildRequires:  pkgconfig(json-glib-1.0)

%description
The Facebook protocol plugin for bitlbee. This plugin uses the Facebook Mobile API.

%prep
%setup -q

%build
%if 0%{?from_checkout}
./autogen.sh
%endif
%configure
make %{?_smp_mflags}
 
%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm %{buildroot}%{_libdir}/bitlbee/facebook.la

%files
%doc ChangeLog README COPYING
%dir %{_libdir}/bitlbee
%{_libdir}/bitlbee/facebook.so

%changelog
* Thu Feb 25 2021 mcepl@cepl.eu
- Update to version 1.2.2+git.1614281748.a31ccbe:
  * configure: drop the unnecessary AC_PROG_CC macro check (#211)
  * Release 1.2.2
  * configure: change obsolete AC_PROG_CC_C99 for AC_PROG_CC
  * Force sync_interval to the new default if it's 5 minutes or lower
  * Replace travis with github actions, fix OBS (#210)
* Thu Feb  4 2021 mcepl@cepl.eu
- Update to version 1.2.1+git.1611145185.49ea312:
  * Bump the FB_ORCA_AGENT version once again (#208)
  * Remove bash-ism in configure.ac
  * Port away from deprecated g_type_class_add_private() and friends
  * Increase default sync_interval from 5 to 1440
  * travis: replace python-m2crypto dependency with python3-m2crypto
  * facebook-api: Fix id assertion in fb_api_cb_publish_mst() (#204)
  * travis: add python-m2crypto to dependencies for OBS deploy
  * Release 1.2.1 with fixes for a couple of server changes
  * Fix taNewMessage bug (#202)
  * fb_api_cb_publish_pt: check field is stop (#199)
* Sun Oct 25 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.2.1:
  - Fix "Parse error: unexpected identifier 'taNewMessage'"
    (gh#bitlbee/bitlbee-facebook#200)
  - Fix "Failed to read thrift: facebook-api.c:1929
    fb_api_cb_publish_pt: assertion 'fb_thrift_read_stop(thft)' failed"
    (gh#bitlbee/bitlbee-facebook#197)
* Thu Mar 14 2019 Tomas Cech <sleep_walker@opensuse.org>
- Version bump 1.2.0
  - Fix ERROR_QUEUE_OVERFLOW on login by bumping orca agent version
  - Fix "Failed to read fixed header" with TLS 1.3 / GnuTLS 3.6.x
  - Add workplace chat support (enable the "work" setting to use it)
* Sat Sep 16 2017 tampakrap@opensuse.org
- Version bump 1.1.2
  - Fix "Failed to read thrift" with unknown fields in /t_p payload
  - Fix rare login hang/timeout when the last page of contacts is empty
* Thu Apr 20 2017 tampakrap@opensuse.org
- Version bump 1.1.1
  Fixes one last issue to the server side changes from last week.
  - Send orca-formatted user agent for all HTTP requests too. Fixes "Failed
    to parse thread information" errors when joining channels.
  This is in addition to the connection error fixes mentioned in the previous
  release. Quoting from the previous release: "Fix connection errors after
  facebook discontinued support for old versions of facebook messenger for
  android. While most of the protocol implementation was already above that
  version, there was a subtle change that broke fetching of sync_sequence_id,
  and the previously empty MQTT user agent string is now considered an old
  version too (#138)"
  I waited a few days before releasing this to ensure things calm down,
  hopefully it continues like this.
- Version 1.1.0
  Long overdue release, with a year worth of changes. This is now the minimum
  required version.
  - Fix connection errors after facebook discontinued support for old versions
    of facebook messenger for android. While most of the protocol
    implementation was already above that version, there was a subtle change
    that broke fetching of sync_sequence_id, and the previously empty MQTT user
    agent string is now considered an old version too (#138)
  - Fix receiving topic/groupchat membership events (#119)
  - Fix creating channels, inviting, kicking members (#120)
  - Fix setting channel topics (#121)
  - Fix contacts pagination for accounts with more than 500 friends (#74)
  - Fix chats with only two members including self, like the Marketplace ones
  - Fix crash on some kinds of SSL connection failure (#82)
  - Fix crash when glib is compiled with G_ENABLE_DEBUG
  - Deduplicate echoes of sent messages (#76)
  - Set a non-empty HTTP user agent for api/graphql queries, since the empty
    user agent often gets flagged for suspicious activity (#108)
  - Prevent disconnections due to contacts with incomplete profiles (#89)
  - Prevent disconnections on invalid attachment errors (#73)
  - Prevent disconnections when trying to join a chat after being kicked (#244)
  - Use FetchContactsDeltaQuery to incrementally sync contacts. Uses less
    traffic, can be done more often and fixes issues with non-friends (#116)
  - Parse URL attachments generated by the android share feature (#97)
  - Add mark_read_reply setting to only mark messages as read on reply (#69)
  - Add support for the bitlbee 3.5 plugin information API (bitlbee 3.4 is
    still supported by this version, but will be dropped in the next one)
  - Improve url comparison to avoid showing urls twice on attachments
* Fri Aug 12 2016 tampakrap@opensuse.org
- Initial commit
